@@ -5,8 +5,8 @@ blav_model_fit <- function(lavpartable = NULL,
                            VCOV        = NULL, 
                            TEST        = NULL) {
 
-    stopifnot(is.list(lavpartable), class(lavmodel) %in% c("Model",
-                                                           "lavModel"))
+    stopifnot(is.list(lavpartable), inherits(lavmodel, c("Model",
+                                                           "lavModel")))
     if(class(lavjags) != "NULL"){
         lavmcmc <- make_mcmc(lavjags)
     } else {
